@@ -21,8 +21,8 @@ is a thin wrapper over :meth:`~matplotlib.figure.Figure.colorbar`.
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-from matplotlib.externals import six
-from matplotlib.externals.six.moves import xrange, zip
+import six
+from six.moves import xrange, zip
 
 import numpy as np
 import matplotlib as mpl
@@ -374,9 +374,8 @@ class ColorbarBase(cm.ScalarMappable):
         if format is None:
             if isinstance(self.norm, colors.LogNorm):
                 # change both axis for proper aspect
-                self.ax.xaxis.set_scale("log")
-                self.ax.yaxis.set_scale("log")
-                self.ax._update_transScale()
+                self.ax.set_xscale("log")
+                self.ax.set_yscale("log")
                 self.cbar_axis.set_minor_locator(ticker.NullLocator())
                 formatter = ticker.LogFormatter()
             else:
@@ -821,7 +820,7 @@ def colorbar(mappable, cax=None, ax=None, **kw):
         ax = plt.gca()
     if cax is None:
         cax, kw = make_axes(ax, **kw)
-    cax.hold(True)
+    cax._hold = True
     cb = Colorbar(cax, mappable, **kw)
 
     def on_changed(m):
